PriceNotifier class
Riverpod StateNotifier that exposes TokenPrices as an AsyncValue.
Initialises immediately from the local cache, then triggers a live refresh.
- Inheritance
-
- Object
- StateNotifier<
AsyncValue< TokenPrices> > - PriceNotifier
Constructors
- PriceNotifier(PriceService _service)
Properties
-
debugState
→ AsyncValue<
TokenPrices> -
A development-only way to access
stateoutside ofStateNotifier.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
If a listener has been added using
addListenerand hasn't been removed yet.no setterinherited - mounted → bool
-
Whether
disposewas called or not.no setterinherited - onError ↔ ErrorListener?
-
A callback for error reporting if one of the listeners added with
addListenerthrows.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ AsyncValue<
TokenPrices> -
The current "state" of this
StateNotifier.getter/setter pairinherited -
stream
→ Stream<
AsyncValue< TokenPrices> > -
A broadcast stream representation of a
StateNotifier.no setterinherited
Methods
-
addListener(
Listener< AsyncValue< listener, {bool fireImmediately = true}) → RemoveListenerTokenPrices> > -
Subscribes to this object.
inherited
-
dispose(
) → void -
Frees all the resources associated with this object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< void> - Triggers a live price fetch and updates state. If the fetch fails and prices are already loaded, the existing value is kept.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
AsyncValue< TokenPrices> old, AsyncValue<TokenPrices> current) → bool -
Whether to notify listeners or not when
statechangesinherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited