RecentWallet class

Constructors

RecentWallet({required String address, String? domain, required DateTime lastPaid})
RecentWallet.fromJson(Map<String, dynamic> json)
factory

Properties

address String
final
domain String?
final
hashCode int
The hash code for this object.
no setterinherited
lastPaid DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited