SimulationResult class
Result of a simulateTransaction RPC call.
Constructors
- SimulationResult({required bool hasError, dynamic error})
Properties
- error → dynamic
-
The raw error value returned by the RPC node, or
nullon success.final - hasError → bool
-
truewhen the simulation returned a non-null error field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited